@@ -249,6 +249,9 @@ void DockItem::showContextMenu()
     hidePopup();
     emit requestWindowAutoHide(false);
 
+    if (!m_contextMenu.parentWidget())
+        m_contextMenu.setParent(topLevelWidget(), Qt::Popup);
+
     m_contextMenu.exec(QCursor::pos());
 
     onContextMenuAccepted();
