@@ -149,7 +149,7 @@ QRect MultiScreenWorker::dockRect(const QString &screenName)
  */
 QRect MultiScreenWorker::dockRectWithoutScale(const QString &screenName, const Position &pos, const HideMode &hideMode, const DisplayMode &displayMode)
 {
-    if (hideMode == HideMode::KeepShowing)
+    if (hideMode == HideMode::KeepShowing || m_currentHideState == HideState::Show)
         return getDockShowGeometry(screenName, pos, displayMode, true);
     else
         return getDockHideGeometry(screenName, pos, displayMode, true);
@@ -660,10 +660,10 @@ void MultiScreenWorker::onRequestUpdateRegionMonitor()
 
 void MultiScreenWorker::onRequestUpdateFrontendGeometry()
 {
-    const QRect rect = dockRectWithoutScale(m_ds.current(), m_position, HideMode::KeepShowing, m_displayMode);
+    const QRect rect = dockRectWithoutScale(m_ds.current(), m_position, m_hideMode, m_displayMode);
 
-    //!!! 向com.deepin.dde.daemon.Dock的SetFrontendWindowRect接口设置区域时,此区域的高度或宽度不能为0,否则会导致其HideState属性循环切换,造成任务栏循环显示或隐藏
-    if (rect.width() == 0 || rect.height() == 0)
+    //!!! 智能隐藏模式下隐藏之后不需要在设置一次，否则会导致HideState属性循环变化
+    if (m_hideMode == HideMode::SmartHide && m_currentHideState == HideState::Hide)
         return;
 
 #ifdef QT_DEBUG
@@ -1024,6 +1024,7 @@ void MultiScreenWorker::displayAnimation(const QString &screen, const Position &
             || testState(ShowAnimationStart))
         return;
 
+    m_currentHideState = act ? HideState::Hide : HideState::Show;
     QRect mainwindowRect = parent()->geometry();
     QRect dockShowRect = getDockShowGeometry(screen, pos, m_displayMode);
     QRect dockHideRect = getDockHideGeometry(screen, pos, m_displayMode);
@@ -1408,11 +1409,13 @@ void MultiScreenWorker::checkXEventMonitorService()
             // 在鼠标拖动任务栏在最大尺寸的时候，如果当前任务栏为隐藏模式（一直隐藏或智能隐藏），在松开鼠标的那一刻，判断当前
             // 鼠标位置是否在任务栏外面(isCursorOut(x,y)==true)，此时需要触发onExtralRegionMonitorChanged函数，
             // 目的是为了让其触发隐藏
-            if (isCursorOut(x, y)
-                    && (m_hideMode == HideMode::KeepHidden || m_hideMode == HideMode::SmartHide)) {
-                qApp->setProperty("DRAG_STATE", false);
-                onExtralRegionMonitorChanged(0, 0, m_extralRegisterKey);
-            }
+            QTimer::singleShot(50, this, [ = ] {
+                if (isCursorOut(x, y)
+                        && (m_hideMode == HideMode::KeepHidden || m_hideMode == HideMode::SmartHide)) {
+                    qApp->setProperty("DRAG_STATE", false);
+                    onExtralRegionMonitorChanged(0, 0, m_extralRegisterKey);
+                }
+            });
         });
 
         connect(extralEventInter, &XEventMonitor::CursorOut, this, [ = ](int x, int y, const QString &key) {
@@ -1429,7 +1432,9 @@ void MultiScreenWorker::checkXEventMonitorService()
         });
 
         // 触屏时，后端只发送press、release消息，有move消息则为鼠标，press置false
-        connect(touchEventInter, &XEventMonitor::CursorMove, this, [ = ] { setStates(TouchPress, false); });
+        connect(touchEventInter, &XEventMonitor::CursorMove, this, [ = ] {
+            setStates(Utils::IS_WAYLAND_DISPLAY? MousePress : TouchPress, false);
+        });
         connect(touchEventInter, &XEventMonitor::ButtonPress, this, &MultiScreenWorker::onTouchPress);
         connect(touchEventInter, &XEventMonitor::ButtonRelease, this, &MultiScreenWorker::onTouchRelease);
     };
