@@ -358,6 +358,8 @@ void SoundApplet::cardsChanged(const QString &cards)
     }
 
     onDefaultSinkChanged();//重新获取切换的设备信息
+
+    // 判断是否存在激活的输出设备
     enableDevice(existActiveOutputDevice());
 
     for (Port *port : m_ports) {
@@ -646,13 +648,9 @@ bool SoundApplet::eventFilter(QObject *watcher, QEvent *event)
 {
     // 当控制中心禁用所有输出设备时，静音按钮置灰，其他情况正常．
     if (watcher == m_volumeIconMin && event->type() == QEvent::MouseButtonRelease) {
-        if (!existActiveOutputDevice()) {
-            m_volumeIconMin->setEnabled(false);
-        } else {
-            m_volumeIconMin->setEnabled(true);
-            m_defSinkInter->SetMuteQueued(!m_defSinkInter->mute());
-        }
+        m_defSinkInter->SetMuteQueued(!m_defSinkInter->mute());
     }
+
     return false;
 }
 
