@@ -67,6 +67,13 @@ private slots:
     bool isBadWindow();
 
 private:
+    // Direct client关注xevent，使用xevent来处理button事件等
+    // XTest client不关注xevent，使用xtest extension处理
+    enum InjectMode {
+        Direct,
+        XTest,
+    };
+
     bool m_active = false;
     WId m_windowId;
     WId m_containerWid;
@@ -78,6 +85,7 @@ private:
     bool m_valid;
     xcb_connection_t *m_xcbCnn;
     Display* m_display;
+    InjectMode m_injectMode;
 };
 
 #endif // XEMBEDTRAYWIDGET_H
