@@ -23,7 +23,7 @@ void Ut_TrayPluginItem::TearDown()
 {
 }
 
-TEST_F(Ut_TrayPluginItem, all_test)
+TEST_F(Ut_TrayPluginItem, coverage_test)
 {
     TestPlugin plugin;
     TrayPluginItem item(&plugin, "", "");
@@ -33,11 +33,11 @@ TEST_F(Ut_TrayPluginItem, all_test)
     item.setSuggestIconSize(QSize());
     item.setRightSplitVisible(true);
 
-    ASSERT_EQ(item.trayVisableItemCount(), 0);
+    ASSERT_EQ(item.trayVisibleItemCount(), 0);
 
     QMouseEvent event(QEvent::MouseButtonPress, QPointF(), Qt::NoButton, Qt::NoButton, Qt::NoModifier);
     qApp->sendEvent(item.centralWidget(), &event);
 
     QDynamicPropertyChangeEvent event1("TrayVisableItemCount");
-    qApp->sendEvent(item.centralWidget(), &event);
+    qApp->sendEvent(item.centralWidget(), &event1);
 }
